@@ -26,7 +26,13 @@ fi
 
 
 if [ -n "$QML_IMPORT_PATH" ]; then
-	export QML_IMPORT_PATH="/opt/qtm12/imports:$QML_IMPORT_PATH"
+	export QML_IMPORT_PATH="/opt/meecolay/lib/qt4/imports:/opt/qtm12/imports:$QML_IMPORT_PATH"
 else
-	export QML_IMPORT_PATH="/opt/qtm12/imports"
+	export QML_IMPORT_PATH="/opt/meecolay/lib/qt4/imports:/opt/qtm12/imports"
+fi
+
+if [ -n "$QT_PLUGIN_PATH" ]; then
+	export QT_PLUGIN_PATH="/opt/meecolay/lib/qt4/plugins:/opt/qtm12/plugins:$QT_PLUGIN_PATH"
+else
+	export QT_PLUGIN_PATH="/opt/meecolay/lib/qt4/plugins:/opt/qtm12/plugins"
 fi
